Class: Aws::AppRunner::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppRunner::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-apprunner/client.rb,
sig/client.rbs
Overview
An API client for AppRunner. To construct a client, you need to configure a :region and :credentials.
client = Aws::AppRunner::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateCustomDomainResponseSuccess, _CreateAutoScalingConfigurationResponseSuccess, _CreateConnectionResponseSuccess, _CreateObservabilityConfigurationResponseSuccess, _CreateServiceResponseSuccess, _CreateVpcConnectorResponseSuccess, _CreateVpcIngressConnectionResponseSuccess, _DeleteAutoScalingConfigurationResponseSuccess, _DeleteConnectionResponseSuccess, _DeleteObservabilityConfigurationResponseSuccess, _DeleteServiceResponseSuccess, _DeleteVpcConnectorResponseSuccess, _DeleteVpcIngressConnectionResponseSuccess, _DescribeAutoScalingConfigurationResponseSuccess, _DescribeCustomDomainsResponseSuccess, _DescribeObservabilityConfigurationResponseSuccess, _DescribeServiceResponseSuccess, _DescribeVpcConnectorResponseSuccess, _DescribeVpcIngressConnectionResponseSuccess, _DisassociateCustomDomainResponseSuccess, _ListAutoScalingConfigurationsResponseSuccess, _ListConnectionsResponseSuccess, _ListObservabilityConfigurationsResponseSuccess, _ListOperationsResponseSuccess, _ListServicesForAutoScalingConfigurationResponseSuccess, _ListServicesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVpcConnectorsResponseSuccess, _ListVpcIngressConnectionsResponseSuccess, _PauseServiceResponseSuccess, _ResumeServiceResponseSuccess, _StartDeploymentResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDefaultAutoScalingConfigurationResponseSuccess, _UpdateServiceResponseSuccess, _UpdateVpcIngressConnectionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_custom_domain(params = {}) ⇒ Types::AssociateCustomDomainResponse
Associate your own domain name with the App Runner subdomain URL of your App Runner service.
-
#create_auto_scaling_configuration(params = {}) ⇒ Types::CreateAutoScalingConfigurationResponse
Create an App Runner automatic scaling configuration resource.
-
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Create an App Runner connection resource.
-
#create_observability_configuration(params = {}) ⇒ Types::CreateObservabilityConfigurationResponse
Create an App Runner observability configuration resource.
-
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Create an App Runner service.
-
#create_vpc_connector(params = {}) ⇒ Types::CreateVpcConnectorResponse
Create an App Runner VPC connector resource.
-
#create_vpc_ingress_connection(params = {}) ⇒ Types::CreateVpcIngressConnectionResponse
Create an App Runner VPC Ingress Connection resource.
-
#delete_auto_scaling_configuration(params = {}) ⇒ Types::DeleteAutoScalingConfigurationResponse
Delete an App Runner automatic scaling configuration resource.
-
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Delete an App Runner connection.
-
#delete_observability_configuration(params = {}) ⇒ Types::DeleteObservabilityConfigurationResponse
Delete an App Runner observability configuration resource.
-
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Delete an App Runner service.
-
#delete_vpc_connector(params = {}) ⇒ Types::DeleteVpcConnectorResponse
Delete an App Runner VPC connector resource.
-
#delete_vpc_ingress_connection(params = {}) ⇒ Types::DeleteVpcIngressConnectionResponse
Delete an App Runner VPC Ingress Connection resource that's associated with an App Runner service.
-
#describe_auto_scaling_configuration(params = {}) ⇒ Types::DescribeAutoScalingConfigurationResponse
Return a full description of an App Runner automatic scaling configuration resource.
-
#describe_custom_domains(params = {}) ⇒ Types::DescribeCustomDomainsResponse
Return a description of custom domain names that are associated with an App Runner service.
-
#describe_observability_configuration(params = {}) ⇒ Types::DescribeObservabilityConfigurationResponse
Return a full description of an App Runner observability configuration resource.
-
#describe_service(params = {}) ⇒ Types::DescribeServiceResponse
Return a full description of an App Runner service.
-
#describe_vpc_connector(params = {}) ⇒ Types::DescribeVpcConnectorResponse
Return a description of an App Runner VPC connector resource.
-
#describe_vpc_ingress_connection(params = {}) ⇒ Types::DescribeVpcIngressConnectionResponse
Return a full description of an App Runner VPC Ingress Connection resource.
-
#disassociate_custom_domain(params = {}) ⇒ Types::DisassociateCustomDomainResponse
Disassociate a custom domain name from an App Runner service.
-
#list_auto_scaling_configurations(params = {}) ⇒ Types::ListAutoScalingConfigurationsResponse
Returns a list of active App Runner automatic scaling configurations in your Amazon Web Services account.
-
#list_connections(params = {}) ⇒ Types::ListConnectionsResponse
Returns a list of App Runner connections that are associated with your Amazon Web Services account.
-
#list_observability_configurations(params = {}) ⇒ Types::ListObservabilityConfigurationsResponse
Returns a list of active App Runner observability configurations in your Amazon Web Services account.
-
#list_operations(params = {}) ⇒ Types::ListOperationsResponse
Return a list of operations that occurred on an App Runner service.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Returns a list of running App Runner services in your Amazon Web Services account.
-
#list_services_for_auto_scaling_configuration(params = {}) ⇒ Types::ListServicesForAutoScalingConfigurationResponse
Returns a list of the associated App Runner services using an auto scaling configuration.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags that are associated with for an App Runner resource.
-
#list_vpc_connectors(params = {}) ⇒ Types::ListVpcConnectorsResponse
Returns a list of App Runner VPC connectors in your Amazon Web Services account.
-
#list_vpc_ingress_connections(params = {}) ⇒ Types::ListVpcIngressConnectionsResponse
Return a list of App Runner VPC Ingress Connections in your Amazon Web Services account.
-
#pause_service(params = {}) ⇒ Types::PauseServiceResponse
Pause an active App Runner service.
-
#resume_service(params = {}) ⇒ Types::ResumeServiceResponse
Resume an active App Runner service.
-
#start_deployment(params = {}) ⇒ Types::StartDeploymentResponse
Initiate a manual deployment of the latest commit in a source code repository or the latest image in a source image repository to an App Runner service.
-
#tag_resource(params = {}) ⇒ Struct
Add tags to, or update the tag values of, an App Runner resource.
-
#untag_resource(params = {}) ⇒ Struct
Remove tags from an App Runner resource.
-
#update_default_auto_scaling_configuration(params = {}) ⇒ Types::UpdateDefaultAutoScalingConfigurationResponse
Update an auto scaling configuration to be the default.
-
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Update an App Runner service.
-
#update_vpc_ingress_connection(params = {}) ⇒ Types::UpdateVpcIngressConnectionResponse
Update an existing App Runner VPC Ingress Connection resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-apprunner/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3019 3020 3021 |
# File 'lib/aws-sdk-apprunner/client.rb', line 3019 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3022 3023 3024 |
# File 'lib/aws-sdk-apprunner/client.rb', line 3022 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_custom_domain(params = {}) ⇒ Types::AssociateCustomDomainResponse
Associate your own domain name with the App Runner subdomain URL of your App Runner service.
After you call AssociateCustomDomain and receive a successful
response, use the information in the CustomDomain record that's
returned to add CNAME records to your Domain Name System (DNS). For
each mapped domain name, add a mapping to the target App Runner
subdomain and one or more certificate validation records. App Runner
then performs DNS validation to verify that you own or control the
domain name that you associated. App Runner tracks domain validity in
a certificate stored in AWS Certificate Manager (ACM).
90 |
# File 'sig/client.rbs', line 90
def associate_custom_domain: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 |
# File 'lib/aws-sdk-apprunner/client.rb', line 2992 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppRunner') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-apprunner' context[:gem_version] = '1.75.0' Seahorse::Client::Request.new(handlers, context) end |
#create_auto_scaling_configuration(params = {}) ⇒ Types::CreateAutoScalingConfigurationResponse
Create an App Runner automatic scaling configuration resource. App Runner requires this resource when you create or update App Runner services and you require non-default auto scaling settings. You can share an auto scaling configuration across multiple services.
Create multiple revisions of a configuration by calling this action
multiple times using the same AutoScalingConfigurationName. The call
returns incremental AutoScalingConfigurationRevision values. When
you create a service and configure an auto scaling configuration
resource, the service uses the latest active revision of the auto
scaling configuration by default. You can optionally configure the
service to use a specific revision.
Configure a higher MinSize to increase the spread of your App Runner
service over more Availability Zones in the Amazon Web Services
Region. The tradeoff is a higher minimal cost.
Configure a lower MaxSize to control your cost. The tradeoff is
lower responsiveness during peak demand.
102 |
# File 'sig/client.rbs', line 102
def create_auto_scaling_configuration: (
|
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Create an App Runner connection resource. App Runner requires a connection resource when you create App Runner services that access private repositories from certain third-party providers. You can share a connection across multiple services.
A connection resource is needed to access GitHub and Bitbucket repositories. Both require a user interface approval process through the App Runner console before you can use the connection.
121 |
# File 'sig/client.rbs', line 121
def create_connection: (
|
#create_observability_configuration(params = {}) ⇒ Types::CreateObservabilityConfigurationResponse
Create an App Runner observability configuration resource. App Runner requires this resource when you create or update App Runner services and you want to enable non-default observability features. You can share an observability configuration across multiple services.
Create multiple revisions of a configuration by calling this action
multiple times using the same ObservabilityConfigurationName. The
call returns incremental ObservabilityConfigurationRevision values.
When you create a service and configure an observability configuration
resource, the service uses the latest active revision of the
observability configuration by default. You can optionally configure
the service to use a specific revision.
The observability configuration resource is designed to configure
multiple features (currently one feature, tracing). This action takes
optional parameters that describe the configuration of these features
(currently one parameter, TraceConfiguration). If you don't specify
a feature parameter, App Runner doesn't enable the feature.
138 |
# File 'sig/client.rbs', line 138
def create_observability_configuration: (
|
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Create an App Runner service. After the service is created, the action also automatically starts a deployment.
This is an asynchronous operation. On a successful call, you can use
the returned OperationId and the ListOperations call to track
the operation's progress.
158 |
# File 'sig/client.rbs', line 158
def create_service: (
|
#create_vpc_connector(params = {}) ⇒ Types::CreateVpcConnectorResponse
Create an App Runner VPC connector resource. App Runner requires this resource when you want to associate your App Runner service to a custom Amazon Virtual Private Cloud (Amazon VPC).
190 |
# File 'sig/client.rbs', line 190
def create_vpc_connector: (
|
#create_vpc_ingress_connection(params = {}) ⇒ Types::CreateVpcIngressConnectionResponse
Create an App Runner VPC Ingress Connection resource. App Runner requires this resource when you want to associate your App Runner service with an Amazon VPC endpoint.
208 |
# File 'sig/client.rbs', line 208
def create_vpc_ingress_connection: (
|
#delete_auto_scaling_configuration(params = {}) ⇒ Types::DeleteAutoScalingConfigurationResponse
Delete an App Runner automatic scaling configuration resource. You can delete a top level auto scaling configuration, a specific revision of one, or all revisions associated with the top level configuration. You can't delete the default auto scaling configuration or a configuration that's used by one or more App Runner services.
229 |
# File 'sig/client.rbs', line 229
def delete_auto_scaling_configuration: (
|
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Delete an App Runner connection. You must first ensure that there are
no running App Runner services that use this connection. If there are
any, the DeleteConnection action fails.
240 |
# File 'sig/client.rbs', line 240
def delete_connection: (
|
#delete_observability_configuration(params = {}) ⇒ Types::DeleteObservabilityConfigurationResponse
Delete an App Runner observability configuration resource. You can delete a specific revision or the latest active revision. You can't delete a configuration that's used by one or more App Runner services.
250 |
# File 'sig/client.rbs', line 250
def delete_observability_configuration: (
|
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Delete an App Runner service.
This is an asynchronous operation. On a successful call, you can use
the returned OperationId and the ListOperations call to track the
operation's progress.
261 |
# File 'sig/client.rbs', line 261
def delete_service: (
|
#delete_vpc_connector(params = {}) ⇒ Types::DeleteVpcConnectorResponse
Delete an App Runner VPC connector resource. You can't delete a connector that's used by one or more App Runner services.
271 |
# File 'sig/client.rbs', line 271
def delete_vpc_connector: (
|
#delete_vpc_ingress_connection(params = {}) ⇒ Types::DeleteVpcIngressConnectionResponse
Delete an App Runner VPC Ingress Connection resource that's associated with an App Runner service. The VPC Ingress Connection must be in one of the following states to be deleted:
-
AVAILABLE -
FAILED_CREATION -
FAILED_UPDATE -
FAILED_DELETION
281 |
# File 'sig/client.rbs', line 281
def delete_vpc_ingress_connection: (
|
#describe_auto_scaling_configuration(params = {}) ⇒ Types::DescribeAutoScalingConfigurationResponse
Return a full description of an App Runner automatic scaling configuration resource.
291 |
# File 'sig/client.rbs', line 291
def describe_auto_scaling_configuration: (
|
#describe_custom_domains(params = {}) ⇒ Types::DescribeCustomDomainsResponse
Return a description of custom domain names that are associated with an App Runner service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
305 |
# File 'sig/client.rbs', line 305
def describe_custom_domains: (
|
#describe_observability_configuration(params = {}) ⇒ Types::DescribeObservabilityConfigurationResponse
Return a full description of an App Runner observability configuration resource.
317 |
# File 'sig/client.rbs', line 317
def describe_observability_configuration: (
|
#describe_service(params = {}) ⇒ Types::DescribeServiceResponse
Return a full description of an App Runner service.
327 |
# File 'sig/client.rbs', line 327
def describe_service: (
|
#describe_vpc_connector(params = {}) ⇒ Types::DescribeVpcConnectorResponse
Return a description of an App Runner VPC connector resource.
337 |
# File 'sig/client.rbs', line 337
def describe_vpc_connector: (
|
#describe_vpc_ingress_connection(params = {}) ⇒ Types::DescribeVpcIngressConnectionResponse
Return a full description of an App Runner VPC Ingress Connection resource.
347 |
# File 'sig/client.rbs', line 347
def describe_vpc_ingress_connection: (
|
#disassociate_custom_domain(params = {}) ⇒ Types::DisassociateCustomDomainResponse
Disassociate a custom domain name from an App Runner service.
Certificates tracking domain validity are associated with a custom domain and are stored in AWS Certificate Manager (ACM). These certificates aren't deleted as part of this action. App Runner delays certificate deletion for 30 days after a domain is disassociated from your service.
360 |
# File 'sig/client.rbs', line 360
def disassociate_custom_domain: (
|
#list_auto_scaling_configurations(params = {}) ⇒ Types::ListAutoScalingConfigurationsResponse
Returns a list of active App Runner automatic scaling configurations in your Amazon Web Services account. You can query the revisions for a specific configuration name or the revisions for all active configurations in your account. You can optionally query only the latest revision of each requested name.
To retrieve a full description of a particular configuration revision,
call and provide one of the ARNs returned by
ListAutoScalingConfigurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
372 |
# File 'sig/client.rbs', line 372
def list_auto_scaling_configurations: (
|
#list_connections(params = {}) ⇒ Types::ListConnectionsResponse
Returns a list of App Runner connections that are associated with your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
386 |
# File 'sig/client.rbs', line 386
def list_connections: (
|
#list_observability_configurations(params = {}) ⇒ Types::ListObservabilityConfigurationsResponse
Returns a list of active App Runner observability configurations in your Amazon Web Services account. You can query the revisions for a specific configuration name or the revisions for all active configurations in your account. You can optionally query only the latest revision of each requested name.
To retrieve a full description of a particular configuration revision,
call and provide one of the ARNs returned by
ListObservabilityConfigurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
399 |
# File 'sig/client.rbs', line 399
def list_observability_configurations: (
|
#list_operations(params = {}) ⇒ Types::ListOperationsResponse
Return a list of operations that occurred on an App Runner service.
The resulting list of OperationSummary objects is sorted in reverse chronological order. The first object on the list represents the last started operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
413 |
# File 'sig/client.rbs', line 413
def list_operations: (
|
#list_services(params = {}) ⇒ Types::ListServicesResponse
Returns a list of running App Runner services in your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
426 |
# File 'sig/client.rbs', line 426
def list_services: (
|
#list_services_for_auto_scaling_configuration(params = {}) ⇒ Types::ListServicesForAutoScalingConfigurationResponse
Returns a list of the associated App Runner services using an auto scaling configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
438 |
# File 'sig/client.rbs', line 438
def list_services_for_auto_scaling_configuration: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags that are associated with for an App Runner resource. The response contains a list of tag key-value pairs.
450 |
# File 'sig/client.rbs', line 450
def list_tags_for_resource: (
|
#list_vpc_connectors(params = {}) ⇒ Types::ListVpcConnectorsResponse
Returns a list of App Runner VPC connectors in your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
461 |
# File 'sig/client.rbs', line 461
def list_vpc_connectors: (
|
#list_vpc_ingress_connections(params = {}) ⇒ Types::ListVpcIngressConnectionsResponse
Return a list of App Runner VPC Ingress Connections in your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
473 |
# File 'sig/client.rbs', line 473
def list_vpc_ingress_connections: (
|
#pause_service(params = {}) ⇒ Types::PauseServiceResponse
Pause an active App Runner service. App Runner reduces compute capacity for the service to zero and loses state (for example, ephemeral storage is removed).
This is an asynchronous operation. On a successful call, you can use
the returned OperationId and the ListOperations call to track the
operation's progress.
489 |
# File 'sig/client.rbs', line 489
def pause_service: (
|
#resume_service(params = {}) ⇒ Types::ResumeServiceResponse
Resume an active App Runner service. App Runner provisions compute capacity for the service.
This is an asynchronous operation. On a successful call, you can use
the returned OperationId and the ListOperations call to track the
operation's progress.
500 |
# File 'sig/client.rbs', line 500
def resume_service: (
|
#start_deployment(params = {}) ⇒ Types::StartDeploymentResponse
Initiate a manual deployment of the latest commit in a source code repository or the latest image in a source image repository to an App Runner service.
For a source code repository, App Runner retrieves the commit and builds a Docker image. For a source image repository, App Runner retrieves the latest Docker image. In both cases, App Runner then deploys the new image to your service and starts a new container instance.
This is an asynchronous operation. On a successful call, you can use
the returned OperationId and the ListOperations call to track the
operation's progress.
510 |
# File 'sig/client.rbs', line 510
def start_deployment: (
|
#tag_resource(params = {}) ⇒ Struct
Add tags to, or update the tag values of, an App Runner resource. A tag is a key-value pair.
519 |
# File 'sig/client.rbs', line 519
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove tags from an App Runner resource.
534 |
# File 'sig/client.rbs', line 534
def untag_resource: (
|
#update_default_auto_scaling_configuration(params = {}) ⇒ Types::UpdateDefaultAutoScalingConfigurationResponse
Update an auto scaling configuration to be the default. The existing default auto scaling configuration will be set to non-default automatically.
545 |
# File 'sig/client.rbs', line 545
def update_default_auto_scaling_configuration: (
|
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Update an App Runner service. You can update the source configuration and instance configuration of the service. You can also update the ARN of the auto scaling configuration resource that's associated with the service. However, you can't change the name or the encryption configuration of the service. These can be set only when you create the service.
To update the tags applied to your service, use the separate actions TagResource and UntagResource.
This is an asynchronous operation. On a successful call, you can use
the returned OperationId and the ListOperations call to track the
operation's progress.
556 |
# File 'sig/client.rbs', line 556
def update_service: (
|
#update_vpc_ingress_connection(params = {}) ⇒ Types::UpdateVpcIngressConnectionResponse
Update an existing App Runner VPC Ingress Connection resource. The VPC Ingress Connection must be in one of the following states to be updated:
-
AVAILABLE
-
FAILED_CREATION
-
FAILED_UPDATE
579 |
# File 'sig/client.rbs', line 579
def update_vpc_ingress_connection: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3012 3013 3014 |
# File 'lib/aws-sdk-apprunner/client.rb', line 3012 def waiter_names [] end |