Class: Aws::AppRunner::Types::ListOperationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppRunner::Types::ListOperationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apprunner/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to include in each response (result page).
-
#next_token ⇒ String
A token from a previous result page.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the App Runner service that you want a list of operations for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to include in each response (result page). It's used for a paginated request.
If you don't specify MaxResults, the request retrieves all
available results in a single response.
1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-apprunner/types.rb', line 1879 class ListOperationsRequest < Struct.new( :service_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token from a previous result page. It's used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones specified in the initial request.
If you don't specify NextToken, the request retrieves the first
result page.
1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-apprunner/types.rb', line 1879 class ListOperationsRequest < Struct.new( :service_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the App Runner service that you want a list of operations for.
1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-apprunner/types.rb', line 1879 class ListOperationsRequest < Struct.new( :service_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |